#include "stdafx.h"
#include <stdio.h>
#include <string.h>
#include <time.h>

//
// Symbol Definitions
//
#define SUCCESS			0
#define SUCCESS_INFO	1
#define FAIL			-1
#define TRUE			1

//
// Error Handler
//
long error (long *rc, long scode, char *loc_str, char *err_str)
{
switch (scode)							/* Look at the success code argument: */
  {
  case 'Z':								/* If success is a zero value, and	  */
    if (*rc == 0)						/* *rc is zero,						  */
      {
      *rc = SUCCESS;					/* set passed status to success, and  */
      return 0;							/* return "error == false".			  */
      }

    break;


  case 'NZ':							/* If success is a nonzero value, and */
    if (*rc != 0)						/* *rc is nonzero,					  */
      {
      *rc = SUCCESS;					/* set passed status to success, and  */
      return 0;							/* return "error == false"			  */
      }

    break;


  case 'NN':							/* If success is a nonnegative value, */
    if (*rc >= 0)						/* and *rc is nonnegative,			  */
      {
      *rc = SUCCESS;					/* set passed status to success, and  */
      return 0;							/* return "error == false".			  */
      }

    break;


  case 'NM1':							/* If success is anything except -1,  */
    if (*rc != -1)						/* and *rc is not -1,				  */
      {
      *rc = SUCCESS;					/* set passed status to success, and  */
      return 0;							/* return "error == false".			  */
      }

    break;


  case '1':								/* If success is a 1, and			  */
    if (*rc == 1)						/* *rc == 1,						  */
      {
      *rc = SUCCESS;					/* set passed status to success, and  */
      return 0;							/* return "error == false".			  */
      }

    break;


  case 'GT':							/* If success is a greater than zero  */
										/* value, and						  */
    if (*rc > 0)						/* *rc is greater than zero,		  */
      {
      *rc = SUCCESS;					/* set passed status to success, and  */
      return 0;							/* return "error == false".			  */
      }

    break;


  case 'TF':							/* If success test is "true - false", */
    if (*rc == TRUE)					/* and *rc is 'TRUE',				  */
      {
      *rc = SUCCESS;					/* set passed status to success, and  */
      return 0;							/* return "error == false".			  */
      }

    break;


  case 'ZF':							// If success is a zero value, and
    if (*rc == 0)						// *rc is zero,
      {
      *rc = SUCCESS;					// set passed status to success, and
      return 0;							// return "error == false".
										// (If the "ZF" test fails, we will
										// return a value of FAIL in *rc.)
      }

    break;


  case 'I':								/* If caller just wants to issue a	  */
										/* message,							  */
    break;								/* go send it.						  */


  case 'F':								/* If success test is "unconditional  */
    									/* failure",						  */
    break;								/* go log an error.					  */


  default:								/* If we did not recognize the code...*/
    if ((err_str != NULL) && (strlen (err_str) >= 12))
      {									/* If we have enough space,			  */
      sprintf (err_str, "ERRHAN:%X", scode);
										/* set up an error message.			  */
      }

    break;
  }

  {										/* Beginning of compound statement	  */
										/* block.							  */
  static char	*image_name = "HomeSentinel";
  										/* Image name prefix for error		  */
										/* messages.						  */
  char		msg_str[1024];				/* String for the formatted message.  */
  time_t	now;						/* The current time.				  */


  now = time (0);						/* Get the current time.			  */
  if (scode != 'I')						/* If it's not an information message,*/
    {
    _snprintf (msg_str, 1023, "%s%s: %d, %s: %s", ctime (&now),
					image_name, *rc, loc_str, err_str);
										/* use this format.					  */
    msg_str[1023] = '\0';
    }

  else									/* For information messages,		  */
    {
    _snprintf (msg_str, 1023, "%s%s: %s", ctime (&now), image_name, err_str);
										/* use this format.					  */
    msg_str[1023] = '\0';
    }

  printf ("%s\n\n", msg_str);			/* Display the message, and			  */
  // if (g.logFile != NULL)				/* if the log file is open,			  */
  //   {
  //   fprintf (g.logFile, "%s\n\n", msg_str);
  // 									/* write the message into the log	  */
  // 									/* file, and						  */
  //   fflush (g.logFile);				/* make sure it gets out to the disk  */
  // 									/* in case we crash.				  */
  //   }

  if (scode == 'Z')						/* If it's the system standard		  */
    {									/* success test, we don't change *rc; */
    return 1;							/* we just return "error == true"	  */
    									/* status.							  */
    }

  else if (scode == 'ZF')				// If it's the "ZF" success test,
    {									// return FAIL in *rc.
    *rc = FAIL;
    return 1;
    }

  else if (scode != 'I')				/* Otherwise, if it's not an		  */
    {									/* information message,				  */
    *rc = FAIL;							/* set passed status to our standard  */
										/* error status, and				  */
    return 1;							/* return "error == true" status.	  */
    }

  else									/* For information messages,		  */
    return 0;							/* don't bother rc, just return		  */
    									/* "error == false".				  */
  }										/* End of compound statement block.   */
} // End of error
